@@ -6,7 +6,13 @@ app = Flask(__name__)
 
 
 def main():
-    api.init()
+    try:
+        with open("~/.elastictex", "r") as f:
+            host = f.read().strip()
+    except:
+        host = "localhost:9200"
+
+    api.init(host)
     app.run(debug=True)
 
 
